================================================================
JSON-RPC pre-assembled datasets server using Twisted for Tendril
================================================================

.. image:: https://img.shields.io/travis/chintal/tendril-server-prefab.svg
        :target: https://travis-ci.org/chintal/tendril-server-prefab

.. image:: https://img.shields.io/pypi/v/tendril-server-prefab.svg
        :target: https://pypi.python.org/pypi/tendril-server-prefab


JSON-RPC pre-assembled datasets server using Twisted for Tendril

* License: MIT
* Documentation: http://tendril-server-prefab.readthedocs.org

Features
--------

* TODO
